Package: MOSClip
Title: Multi Omics Survival Clip
Version: 1.4.0
Depends: R (>= 4.4.0)
Authors@R: c(
   person(given = "Paolo", family = "Martini", role = c("aut", "cre"),
          email = "paolo.martini@unibs.it",
          comment = c(ORCID = "0000-0002-0146-1031")),
   person(given = "Anna", family = "Bortolato", role = c("aut"),
           email = "anna.bortolato@unipd.it",
           comment = c(ORCID = "0009-0009-9327-6084")),
   person(given = "Anna", family = "Tanada", role = c("aut"),
           email = "annacarolinaemi.delimatanada@phd.unipd.it",
           comment = c(ORCID = "0000-0003-3224-0538")),
   person(given = "Enrica", family = "Calura", role = c("aut"),
          email = "enrica.calura@unipd.it",
          comment = c(ORCID = "0000-0001-8463-2432")),
   person(given = "Stefania", family = "Pirrotta", role = c("aut"),
          email = "stefania.pirrotta@phd.unipd.it",
          comment = c(ORCID = "0009-0004-0030-217X")),
   person(given = "Federico", family = "Agostinis", role = c("aut"),
          email = "federico.agostinis@outlook.com")
   )
Description: Topological pathway analysis tool able to integrate multi-omics data. It finds survival-associated modules or significant modules for two-class analysis. This tool have two main methods: pathway tests and module tests. The latter method allows the user to dig inside the pathways itself.
License: AGPL-3
Imports: MultiAssayExperiment, methods, survminer, graph, graphite,
        AnnotationDbi, checkmate, ggplot2, gridExtra, igraph, pheatmap,
        survival, RColorBrewer, SuperExactTest, reshape, NbClust,
        S4Vectors, grDevices, graphics, stats, utils, ComplexHeatmap,
        FactoMineR, circlize, corpcor, coxrobust, elasticnet, gRbase,
        ggplotify, qpgraph, org.Hs.eg.db, Matrix
Suggests: RUnit, BiocGenerics, MASS, BiocStyle, knitr, EDASeq,
        rmarkdown, kableExtra, testthat (>= 3.0.0)
Encoding: UTF-8
LazyData: false
biocViews: Software, StatisticalMethod, GraphAndNetwork, Survival,
        Regression, DimensionReduction, Pathways, Reactome
BugReports: https://github.com/CaluraLab/MOSClip/issues
URL: https://github.com/CaluraLab/MOSClip/
Roxygen: list(markdown = TRUE)
RoxygenNote: 7.3.2
VignetteBuilder: knitr
git_url: https://git.bioconductor.org/packages/MOSClip
git_branch: RELEASE_3_22
git_last_commit: b231f21
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.22
Date/Publication: 2025-10-29
NeedsCompilation: no
Packaged: 2025-10-30 05:13:43 UTC; biocbuild
Author: Paolo Martini [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-0146-1031>),
  Anna Bortolato [aut] (ORCID: <https://orcid.org/0009-0009-9327-6084>),
  Anna Tanada [aut] (ORCID: <https://orcid.org/0000-0003-3224-0538>),
  Enrica Calura [aut] (ORCID: <https://orcid.org/0000-0001-8463-2432>),
  Stefania Pirrotta [aut] (ORCID:
    <https://orcid.org/0009-0004-0030-217X>),
  Federico Agostinis [aut]
Maintainer: Paolo Martini <paolo.martini@unibs.it>
