
#' Reactome Pathways Relation data
#' 
#' This is a copy of the file
#' 'https://reactome.org/download/current/ReactomePathwaysRelation.txt'
#' downloaded September 2024. A brand new file can be downloaded using:
#' \link{`downloadPathwayRelationFromReactome`}
#' 
#' @format A txt file with 2 columns: 
#' \describe{
#' \item{V1} {parent}
#' \item{V2} {child}}
#' 
#' @keywords datasets
#' 
#' @source 
#' [Reactome database](https://reactome.org/download/current/ReactomePathwaysRelation.txt)
#' 
#' @name ReactomePathwaysRelation

