% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/extractSummary.R
\name{extractSummaryFromBinary}
\alias{extractSummaryFromBinary}
\title{Extract Summary Binary from MultiOmics Objects}
\usage{
extractSummaryFromBinary(omic, multiOmicObj, n = 3)
}
\arguments{
\item{omic}{a summarized omic}

\item{multiOmicObj}{\code{Omics} object}

\item{n}{maximum number of features to retrieve}
}
\value{
Meant for internal use only. The summary for omic summarized
using binary events.
\item{sigModule}{the original data for significant features}
\item{discrete}{the discrete version of the significant covariates converted
(when needed) into the discrete version}
\item{subset}{data.frame(row.names=names(topGenes), cov=sum binary events)}
\item{covsConsidered}{the name of the considered omic}
}
\description{
Given an omic summarized by 'summarizeToBinaryEvents' extract the most
important features.
}
